agrees

Function agrees 

pub fn agrees(program: &PolydatProgram, image: &Arc<dyn KernelProgram>) -> bool
Whether image has program’s inputs and outputs in the same order, coordinates first — the condition for driving it with indices resolved on program.