source_image

Function source_image 

pub fn source_image(
    program: &PolydatProgram,
    source: &str,
    options: &CompileOptions,
    context: &str,
) -> Option<Arc<dyn KernelProgram>>
The fiber-engine image of a scope compiled from source under options, the same inputs that produced program; None, with a warning, when it cannot stand in for program.