set_task_cycle

Function set_task_cycle 

pub fn set_task_cycle(cycle: u64)
Update the cycle counter in the enclosing FiberContext. Safe to call outside a scope — the update is a no-op if there is no active fiber context (e.g. when the node is evaluated from a unit test that didn’t install one).