rewrite_inline_exprs

Function rewrite_inline_exprs 

pub fn rewrite_inline_exprs(ops: &mut [ParsedOp]) -> HashMap<String, String>
Rewrite inline expressions ({{expr}}) in op template strings to use named binding references ({__expr_N}).

Returns the expression-to-name map for the caller to know what was rewritten.