pub fn request_graceful_stop()Expand description
Record that a stop condition gracefully halted the remaining walk (SRD-83 workload shell). Idempotent.
pub fn request_graceful_stop()Record that a stop condition gracefully halted the remaining walk (SRD-83 workload shell). Idempotent.