pub fn request_stop()Expand description
Programmatically request a session-wide stop. Used by the signal handler, but also available to other lifecycle code that wants to short-circuit the run.
pub fn request_stop()Programmatically request a session-wide stop. Used by the signal handler, but also available to other lifecycle code that wants to short-circuit the run.