Op sequencing: maps cycles to op templates via a ratio-based LUT.
Three sequencing strategies arrange ops within a stanza (one complete rotation through the sequence):
- Bucket (default): interleaved round-robin from ratio buckets
- Interval: evenly spaced by frequency across the stanza
- Concat: all of first op, then all of second, etc.
Structs
- OpSequence
- Maps cycle numbers to op templates using a pre-computed LUT.
Enums
- Sequencer
Type - Sequencing strategy for arranging ops within a stanza.